# CFF MOST tools

Codec for CFF MOST files.

This is for the Amiga compressed text and image viewer written by
Richard Wynn in 1988/89.

Not to be confused with:
* `most` by John E. Davis
* `most` by Uwe Roehm

## Links

* [🏠 home](https://bitplane.net/dev/python/cff-most)
* [🐍 pypi](https://pypi.org/project/cff-most)
* [🐱 github](https://bitplane/cff-most)
* [📄 test data](https://bitplane/cff-most-test-data)

